==> deepin-kwin-debug-5.25.19-4-x86_64.pkg.tar.zst: usr/src/debug/deepin-kwin/deepin-kwin/src/deepin-kwin_autogen/53SMMK2QHZ/qrc_lanczosresources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-kwin/src/deepin-kwin/src/scenes/opengl/shaders/lanczos_core.frag
  0x0,0x0,0x1,0xa3,
  0x23,
  0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x20,0x31,0x34,0x30,0xa,0xa,0x75,0x6e,0x69,
  0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x73,
  0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,
  0x76,0x65,0x63,0x32,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x31,0x36,0x5d,
  0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,0x65,0x63,0x34,0x20,0x6b,
  0x65,0x72,0x6e,0x65,0x6c,0x5b,0x31,0x36,0x5d,0x3b,0xa,0xa,0x69,0x6e,0x20,0x76,
  0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0x6f,
  0x75,0x74,0x20,0x76,0x65,0x63,0x34,0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,
  0x72,0x3b,0xa,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x76,0x6f,
  0x69,0x64,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x65,0x63,0x34,0x20,0x73,
  0x75,0x6d,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x28,0x73,0x61,0x6d,
  0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,
  0x73,0x74,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x30,0x5d,0x3b,
  0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x28,0x69,0x6e,0x74,0x20,0x69,0x20,
  0x3d,0x20,0x31,0x3b,0x20,0x69,0x20,0x3c,0x20,0x31,0x36,0x3b,0x20,0x69,0x2b,0x2b,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,
  0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,
  0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,
  0x20,0x2d,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,
  0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,
  0x72,0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x20,0x2b,0x20,0x6f,0x66,0x66,0x73,0x65,
  0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,
  0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x66,0x72,
  0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x73,0x75,0x6d,0x3b,0xa,0x7d,
  0xa,0xa,
    // /build/deepin-kwin/src/deepin-kwin/src/scenes/opengl/shaders/lanczos.frag
  0x0,0x0,0x1,0x8f,
  0x75,
  0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,
  0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,
  0x6d,0x20,0x76,0x65,0x63,0x32,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x31,
  0x36,0x5d,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,0x65,0x63,0x34,
  0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x31,0x36,0x5d,0x3b,0xa,0xa,0x76,0x61,
  0x72,0x79,0x69,0x6e,0x67,0x20,0x76,0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,
  0x28,0x76,0x6f,0x69,0x64,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x65,0x63,
  0x34,0x20,0x73,0x75,0x6d,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,
  0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,
  0x6c,0x5b,0x30,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x28,0x69,
  0x6e,0x74,0x20,0x69,0x20,0x3d,0x20,0x31,0x3b,0x20,0x69,0x20,0x3c,0x20,0x31,0x36,
  0x3b,0x20,0x69,0x2b,0x2b,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x73,0x75,0x6d,0x20,0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,
  0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x20,0x2d,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,
  0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,
  0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,0x2b,
  0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x73,0x61,0x6d,0x70,
  0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,
  0x74,0x20,0x2b,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,
  0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,0x46,0x72,0x61,0x67,0x43,0x6f,
  0x6c,0x6f,0x72,0x20,0x3d,0x20,0x73,0x75,0x6d,0x3b,0xa,0x7d,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // scenes
  0x0,0x6,
  0x7,0x99,0xc4,0xc3,
  0x0,0x73,
  0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x73,
    // opengl
  0x0,0x6,
  0x7,0x66,0xc4,0xdc,
  0x0,0x6f,
  0x0,0x70,0x0,0x65,0x0,0x6e,0x0,0x67,0x0,0x6c,
    // shaders
  0x0,0x7,
  0x9,0xe7,0xac,0x73,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x73,
    // lanczos_core.frag
  0x0,0x11,
  0xb,0x9c,0x7e,0x77,
  0x0,0x6c,
  0x0,0x61,0x0,0x6e,0x0,0x63,0x0,0x7a,0x0,0x6f,0x0,0x73,0x0,0x5f,0x0,0x63,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
    // lanczos.frag
  0x0,0xc,
  0x8,0x34,0x4e,0x57,
  0x0,0x6c,
  0x0,0x61,0x0,0x6e,0x0,0x63,0x0,0x7a,0x0,0x6f,0x0,0x73,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,
  // :/scenes
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,
  // :/scenes/opengl
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,
  // :/scenes/opengl/shaders
  0x0,0x0,0x0,0x24,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,
  // :/scenes/opengl/shaders/lanczos.frag
  0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xa7,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,
  // :/scenes/opengl/shaders/lanczos_core.frag
  0x0,0x0,0x0,0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x56,0x56,0xd7,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)(); }
   } dummy;
}

==> deepin-kwin-debug-5.25.22-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-kwin/deepin-kwin/src/deepin-kwin_autogen/53SMMK2QHZ/qrc_lanczosresources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-kwin/src/deepin-kwin/src/scenes/opengl/shaders/lanczos_core.frag
  0x0,0x0,0x1,0xa3,
  0x23,
  0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x20,0x31,0x34,0x30,0xa,0xa,0x75,0x6e,0x69,
  0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x73,
  0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,
  0x76,0x65,0x63,0x32,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x31,0x36,0x5d,
  0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,0x65,0x63,0x34,0x20,0x6b,
  0x65,0x72,0x6e,0x65,0x6c,0x5b,0x31,0x36,0x5d,0x3b,0xa,0xa,0x69,0x6e,0x20,0x76,
  0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0x6f,
  0x75,0x74,0x20,0x76,0x65,0x63,0x34,0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,
  0x72,0x3b,0xa,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x76,0x6f,
  0x69,0x64,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x65,0x63,0x34,0x20,0x73,
  0x75,0x6d,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x28,0x73,0x61,0x6d,
  0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,
  0x73,0x74,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x30,0x5d,0x3b,
  0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x28,0x69,0x6e,0x74,0x20,0x69,0x20,
  0x3d,0x20,0x31,0x3b,0x20,0x69,0x20,0x3c,0x20,0x31,0x36,0x3b,0x20,0x69,0x2b,0x2b,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,
  0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,
  0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,
  0x20,0x2d,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,
  0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,
  0x72,0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x20,0x2b,0x20,0x6f,0x66,0x66,0x73,0x65,
  0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,
  0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x66,0x72,
  0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x73,0x75,0x6d,0x3b,0xa,0x7d,
  0xa,0xa,
    // /build/deepin-kwin/src/deepin-kwin/src/scenes/opengl/shaders/lanczos.frag
  0x0,0x0,0x1,0x8f,
  0x75,
  0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,
  0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,
  0x6d,0x20,0x76,0x65,0x63,0x32,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x31,
  0x36,0x5d,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,0x65,0x63,0x34,
  0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x31,0x36,0x5d,0x3b,0xa,0xa,0x76,0x61,
  0x72,0x79,0x69,0x6e,0x67,0x20,0x76,0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,
  0x28,0x76,0x6f,0x69,0x64,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x65,0x63,
  0x34,0x20,0x73,0x75,0x6d,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,
  0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,
  0x6c,0x5b,0x30,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x28,0x69,
  0x6e,0x74,0x20,0x69,0x20,0x3d,0x20,0x31,0x3b,0x20,0x69,0x20,0x3c,0x20,0x31,0x36,
  0x3b,0x20,0x69,0x2b,0x2b,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x73,0x75,0x6d,0x20,0x2b,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,
  0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x2e,0x73,0x74,0x20,0x2d,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,
  0x73,0x5b,0x69,0x5d,0x29,0x20,0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,
  0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x75,0x6d,0x20,0x2b,
  0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x73,0x61,0x6d,0x70,
  0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x2e,0x73,
  0x74,0x20,0x2b,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x73,0x5b,0x69,0x5d,0x29,0x20,
  0x2a,0x20,0x6b,0x65,0x72,0x6e,0x65,0x6c,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,
  0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,0x46,0x72,0x61,0x67,0x43,0x6f,
  0x6c,0x6f,0x72,0x20,0x3d,0x20,0x73,0x75,0x6d,0x3b,0xa,0x7d,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // scenes
  0x0,0x6,
  0x7,0x99,0xc4,0xc3,
  0x0,0x73,
  0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x73,
    // opengl
  0x0,0x6,
  0x7,0x66,0xc4,0xdc,
  0x0,0x6f,
  0x0,0x70,0x0,0x65,0x0,0x6e,0x0,0x67,0x0,0x6c,
    // shaders
  0x0,0x7,
  0x9,0xe7,0xac,0x73,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x73,
    // lanczos_core.frag
  0x0,0x11,
  0xb,0x9c,0x7e,0x77,
  0x0,0x6c,
  0x0,0x61,0x0,0x6e,0x0,0x63,0x0,0x7a,0x0,0x6f,0x0,0x73,0x0,0x5f,0x0,0x63,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
    // lanczos.frag
  0x0,0xc,
  0x8,0x34,0x4e,0x57,
  0x0,0x6c,
  0x0,0x61,0x0,0x6e,0x0,0x63,0x0,0x7a,0x0,0x6f,0x0,0x73,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,
  // :/scenes
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,
  // :/scenes/opengl
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,
  // :/scenes/opengl/shaders
  0x0,0x0,0x0,0x24,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,
  // :/scenes/opengl/shaders/lanczos.frag
  0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xa7,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,
  // :/scenes/opengl/shaders/lanczos_core.frag
  0x0,0x0,0x0,0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0xd0,0xb9,0x73,0xb8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_lanczosresources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_lanczosresources)(); }
   } dummy;
}
